\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{SIAM2019Paper}[2017/04/25 SIAM2019Paper]



%% Article options
\DeclareOption{10pt}{
	\PassOptionsToClass{\CurrentOption}{article}
}

%% Fallback
\DeclareOption*{
	\ClassWarning{myclass}{Unknown option '\CurrentOption'}
}

%% Custom package options
\DeclareOption{sansserif}{
	\PassOptionsToPackage{\CurrentOption}{paxcommands}
}
\DeclareOption{neverindent}{
	\PassOptionsToPackage{\CurrentOption}{paxcommands}
}

%% Execute default options
\ExecuteOptions{10pt}

%% Process given options
\ProcessOptions\relax

%% Load base class (paper in a4 format)
\LoadClass[a4paper,10pt,twocolumn,]{article}

% Page layout
\RequirePackage[left=2.5cm,right=2.5cm,top=2.5cm,bottom=5.3cm,footskip=3.9cm]{geometry}
\RequirePackage{graphicx}
\setlength{\parindent}{0pt}
\setlength{\parskip}{3pt}

% Amsmath package
\RequirePackage{amsmath}
\RequirePackage{amstext}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{bm}

% Text encoding
\RequirePackage[utf8x]{inputenc}
\RequirePackage[T1]{fontenc}

% Fonts
\RequirePackage{helvet}% Arial font
\renewcommand{\familydefault}{\sfdefault}

% Bibliography
\RequirePackage{natbib}

% Caption formatting
\RequirePackage[font={small,it},justification=RaggedRight,singlelinecheck=false]{caption}

% Paralist
\RequirePackage{paralist}

% hyperlinks
\RequirePackage[colorlinks=true, urlcolor=black, linkcolor=black, 
citecolor=black]{hyperref}

%% Headers/footers: fancyhdr config
\RequirePackage{fancyhdr}
%\pagestyle{empty}

\pagestyle{fancy}  \fancyhead{}
%\fancyfoot[C]{\thepage} \fancyhead[R]{ \footnotesize SIAM 2019, NYU Abu Dhabi}
\fancyfoot[C]{\thepage} 
\fancyhead[R]{ \footnotesize   SIAM 2019, NYU Abu Dhabi}
%\fancyfoot[C]{ \rhead{\thepage}} \fancyhead[R]{ \footnotesize SIAM 2019, NYU Abu Dhabi}


\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}

% Titlesec formatting
\usepackage{titlesec}
\titleformat{\section}[block]
  {\fontsize{10}{18}\bfseries}
  {\thesection}
  {.25cm}
  {\MakeUppercase}
\titleformat{\subsection}[block]
  {\fontsize{10}{-8pt}\bfseries}
  {\thesubsection}
  {.25cm}{}
  [\addvspace{-6pt}]
\titleformat{\subsubsection}[block]
  {\fontsize{10}{-8pt}\itshape}
  {\thesubsubsection}
  {.25cm}{}
  [\addvspace{-6pt}]
\titlespacing*{\section}{0pt}{12pt plus 4pt minus 2pt}{-1pt plus 2pt minus 2pt}
\titlespacing*{\subsection}{0pt}{3pt plus 1pt minus 1pt}{6pt plus 1pt minus  1pt}
\titlespacing*{\subsubsection}{0pt}{3pt plus 1pt minus 1pt}{3pt plus 1pt minus  1pt}

\renewcommand{\bibsection}{}

%% HEADER MACROS SECTION: REQUIRED TO COMPLETE THE TEMPLATE
% bibtex file to be used to create the references
\newcommand{\referencefile}[1]{\newcommand{\bibfile}{#1}}

% short abstract
\newcommand{\shortabstract}[1]{\newcommand{\shortabs}{#1}}

% keywords
\newcommand{\keywords}[1]{\newcommand{\kwords}{#1}}

% Expanding author list with the \addauthor command
\def \authlist {}
\def \affiliationlist {}
\def \corauthormail {}

\newcommand{\addauthor}[2]{
\expandafter\def\expandafter\authlist\expandafter{\authlist{}
    \fontsize{10pt}{12pt}\selectfont #1\textsuperscript{#2}; }
}

\newcommand{\addaffiliation}[2]{
\expandafter\def\expandafter\affiliationlist\expandafter{\affiliationlist{}
    \fontsize{10pt}{12pt}\textsuperscript{#1}\selectfont #2 \\ \vspace{3pt} }
}

\newcommand{\addcorauthormail}[1]{
 \expandafter\def\expandafter\corauthormail\expandafter{\corauthormail{}
    \fontsize{10pt}{12pt}\selectfont #1; }
}

% Patch to allow for text spanning on two pages columns at the beginning of the 
%document
\RequirePackage{etoolbox}
\patchcmd[\long]%   prefix
  {\@topnewpage}%   cmd
  {\@nodocument}{}% search & replace
  {}{}%             success & failure

%% Title page (header, title and authors)
\AtBeginDocument{
\twocolumn[{
\begin{@twocolumnfalse}
\vspace{-14mm}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \begin{minipage}{.60\linewidth}
\begin{flushleft} \setlength{\leftskip}{0.4mm}\setlength{\rightskip}{0mm}
 \noindent Abu Dhabi, March 31st-April 1st, 2019 \\
 \noindent \textbf{3rd International Symposium on Infrastructure Asset}  \\
 \noindent \textbf{Management (SIAM 2019)}
\end{flushleft} 
\end{minipage}
\hfill
\begin{minipage}{.45\linewidth}
\begin{flushright}                                      
    \includegraphics[width=0.69\textwidth]{SIAM_header}
\end{flushright} 
\end{minipage}
    \vspace{7mm}


  \begin{center}
    \fontsize{12pt}{16pt}\selectfont\
    \bf\MakeUppercase\@title
  \end{center}
  \vspace{-18pt}
  \begin{center}
	\authlist
  \end{center}
  \vspace{2ex}
  \begin{center}
    \affiliationlist
    \textsuperscript{*}Corresponding author; e-mail: \corauthormail
  \end{center}   
  \vspace{2ex}
  \begin{flushleft}\setlength{\leftskip}{12mm}\setlength{\rightskip}{12mm}
    \textbf{Abstract}\\ \shortabs
  \end{flushleft}
 \vspace{-10pt}
  \begin{flushleft}\setlength{\leftskip}{12mm}\setlength{\rightskip}{12mm}
    \textbf{Keywords}\\ \kwords
  \end{flushleft}

  \vspace{3ex}
\end{@twocolumnfalse}
}]
\noindent
}

%% Add the reference section at the end of the document
%\AtEndDocument{
%
%}
\endinput